==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/VirtualNetworkGatewaySkuTier.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Gateway SKU tier.
 */
public enum class VirtualNetworkGatewaySkuTier(
    public val javaValue: com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier> {
    Basic(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.Basic),
    HighPerformance(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.HighPerformance),
    Standard(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.Standard),
    UltraPerformance(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.UltraPerformance),
    VpnGw1(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw1),
    VpnGw2(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw2),
    VpnGw3(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw3),
    VpnGw4(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw4),
    VpnGw5(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw5),
    VpnGw1AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw1AZ),
    VpnGw2AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw2AZ),
    VpnGw3AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw3AZ),
    VpnGw4AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw4AZ),
    VpnGw5AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw5AZ),
    ErGw1AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.ErGw1AZ),
    ErGw2AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.ErGw2AZ),
    ErGw3AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.ErGw3AZ),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier):
            VirtualNetworkGatewaySkuTier =
            VirtualNetworkGatewaySkuTier.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/VirtualNetworkGatewaySkuTier.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Gateway SKU tier.
 */
public enum class VirtualNetworkGatewaySkuTier(
    public val javaValue: com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier> {
    Basic(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.Basic),
    HighPerformance(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.HighPerformance),
    Standard(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.Standard),
    UltraPerformance(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.UltraPerformance),
    VpnGw1(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw1),
    VpnGw2(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw2),
    VpnGw3(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw3),
    VpnGw4(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw4),
    VpnGw5(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw5),
    VpnGw1AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw1AZ),
    VpnGw2AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw2AZ),
    VpnGw3AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw3AZ),
    VpnGw4AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw4AZ),
    VpnGw5AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.VpnGw5AZ),
    ErGw1AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.ErGw1AZ),
    ErGw2AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.ErGw2AZ),
    ErGw3AZ(com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier.ErGw3AZ),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.VirtualNetworkGatewaySkuTier): VirtualNetworkGatewaySkuTier =
            VirtualNetworkGatewaySkuTier.values().first { it.javaValue == javaType }
    }
}
